---
title: Basic Hooks
description: Hooks API reference
---

# Basic Hooks

This module contains all the basic built-in hooks contained in `arc`.

!!! note
    Any function that takes a [Context][arc.context.base.Context] as it's sole parameter and returns either `None` or a [`HookResult`][arc.abc.hookable.HookResult] is a valid hook.

::: arc.utils.hooks.basic
